.. _detect:

*****************************************
Source detection tools (`gammapy.detect`)
*****************************************

.. currentmodule:: gammapy.detect

Introduction
============

`gammapy.detect` holds source detection methods that turn event lists or images or cubes
into source catalogs. 

* TODO: Describe references: [Stewart2009]_


Getting Started
===============

* TODO: general intro
* TODO: describe the ``gammapy-iterative-source-detect`` tool.
* TODO: describe the ``gammapy-image-decompose-a-trous`` tool.


Reference/API
=============

.. automodapi:: gammapy.detect
    :no-inheritance-diagram:
